@@ -9,24 +9,30 @@
 #include "access.h"
 #include "access_debug.h"
 #include "accessdialog.h"
+#include "dbushelpers.h"
 #include "request.h"
 #include "utils.h"
 
+#include <QDBusConnection>
 #include <QWindow>
 
+using namespace Qt::StringLiterals;
+
 AccessPortal::AccessPortal(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
 }
 
-uint AccessPortal::AccessDialog(const QDBusObjectPath &handle,
+void AccessPortal::AccessDialog(const QDBusObjectPath &handle,
                                 const QString &app_id,
                                 const QString &parent_window,
                                 const QString &title,
                                 const QString &subtitle,
                                 const QString &body,
                                 const QVariantMap &options,
-                                QVariantMap &results)
+                                const QDBusMessage &message,
+                                [[maybe_unused]] uint &replyResponse,
+                                [[maybe_unused]] QVariantMap &replyResults)
 {
     qCDebug(XdgDesktopPortalKdeAccess) << "AccessDialog called with parameters:";
     qCDebug(XdgDesktopPortalKdeAccess) << "    handle: " << handle.path();
@@ -54,19 +60,18 @@ uint AccessPortal::AccessDialog(const QDBusObjectPath &handle,
         accessDialog->setIcon(options.value(QStringLiteral("icon")).toString());
     }
 
-    // TODO choices
-    Q_UNUSED(results);
+    if (options.contains(u"choices"_s)) {
+        accessDialog->setChoices(qdbus_cast<OptionList>(options.value(u"choices"_s)));
+    }
 
     accessDialog->createDialog();
     Utils::setParentWindow(accessDialog->windowHandle(), parent_window);
     Request::makeClosableDialogRequest(handle, accessDialog);
     accessDialog->windowHandle()->setModality(options.value(QStringLiteral("modal"), true).toBool() ? Qt::WindowModal : Qt::NonModal);
 
-    if (accessDialog->exec()) {
-        accessDialog->deleteLater();
-        return 0;
-    }
-    accessDialog->deleteLater();
-
-    return 1;
+    delayReply(message, accessDialog, this, [accessDialog](DialogResult result) {
+        auto choices = accessDialog->selectedChoices();
+        QVariantMap results{{u"choices"_s, QVariant::fromValue(choices)}};
+        return QVariantList{PortalResponse::fromDialogResult(result), results};
+    });
 }
